=================================================
genomepy: genes and genomes at your fingertips!
=================================================

.. image:: images/logo.png
    :scale: 50 %
    :align: right

*genomepy* is a **python** and **command line** tool aimed at:

* finding
* downloading
* preprocessing
* handling

genomes and gene annotations.

Contents
=========
.. toctree::
   :maxdepth: 1

   Home <self>
   Installation <content/installation>
   Command line documentation <content/command_line>
   Python API documentation (core) <content/api_core>
   Python API documentation (full) <_autosummary/genomepy>
   FAQ <content/help_faq>
   About <content/about>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
